# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2


class ModelPublicServiceStub(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Liveness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Readiness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
                )
        self.ListModelDefinitions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
                )
        self.ListAvailableRegions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListAvailableRegions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsResponse.FromString,
                )
        self.GetModelDefinition = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
                )
        self.ListModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
                )
        self.LookUpModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/LookUpModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
                )
        self.ListNamespaceModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListNamespaceModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsResponse.FromString,
                )
        self.CreateNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelResponse.FromString,
                )
        self.GetNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelResponse.FromString,
                )
        self.UpdateNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelResponse.FromString,
                )
        self.DeleteNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelResponse.FromString,
                )
        self.RenameNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelResponse.FromString,
                )
        self.WatchNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelResponse.FromString,
                )
        self.WatchNamespaceLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchNamespaceLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelResponse.FromString,
                )
        self.ListNamespaceModelVersions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListNamespaceModelVersions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsResponse.FromString,
                )
        self.DeleteNamespaceModelVersion = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModelVersion',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionResponse.FromString,
                )
        self.TriggerNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelResponse.FromString,
                )
        self.TriggerAsyncNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelResponse.FromString,
                )
        self.TriggerNamespaceLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelResponse.FromString,
                )
        self.TriggerAsyncNamespaceLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelResponse.FromString,
                )
        self.TriggerNamespaceModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadResponse.FromString,
                )
        self.TriggerNamespaceLatestModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse.FromString,
                )
        self.GetNamespaceLatestModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetNamespaceLatestModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationResponse.FromString,
                )
        self.GetModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
                )
        self.ListUserModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListUserModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
                )
        self.CreateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
                )
        self.GetUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
                )
        self.UpdateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
                )
        self.DeleteUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
                )
        self.RenameUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
                )
        self.WatchUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
                )
        self.WatchUserLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchUserLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelResponse.FromString,
                )
        self.ListUserModelVersions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListUserModelVersions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsResponse.FromString,
                )
        self.DeleteUserModelVersion = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteUserModelVersion',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionResponse.FromString,
                )
        self.TriggerUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
                )
        self.TriggerAsyncUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelResponse.FromString,
                )
        self.TriggerUserLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelResponse.FromString,
                )
        self.TriggerAsyncUserLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelResponse.FromString,
                )
        self.TriggerUserModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
                )
        self.ListOrganizationModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
                )
        self.CreateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
                )
        self.GetOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
                )
        self.UpdateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
                )
        self.DeleteOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
                )
        self.RenameOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
                )
        self.WatchOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
                )
        self.WatchOrganizationLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchOrganizationLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelResponse.FromString,
                )
        self.ListOrganizationModelVersions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListOrganizationModelVersions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsResponse.FromString,
                )
        self.DeleteOrganizationModelVersion = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModelVersion',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionResponse.FromString,
                )
        self.TriggerOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
                )
        self.TriggerAsyncOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelResponse.FromString,
                )
        self.TriggerOrganizationLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelResponse.FromString,
                )
        self.TriggerAsyncOrganizationLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelResponse.FromString,
                )
        self.TriggerOrganizationModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
                )
        self.GetUserLatestModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserLatestModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationResponse.FromString,
                )
        self.GetOrganizationLatestModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationLatestModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationResponse.FromString,
                )


class ModelPublicServiceServicer(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def Liveness(self, request, context):
        """Check if the model server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the model server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModelDefinitions(self, request, context):
        """List model definitions

        Returns a paginated list of model definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAvailableRegions(self, request, context):
        """List available regions

        Returns a paginated list of available regions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelDefinition(self, request, context):
        """Get a model definition

        Returns the details of a model definition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """List models

        Returns a paginated list of models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpModel(self, request, context):
        """Get a model by UID

        Returns the details of a model by a permalink defined by the resource UID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNamespaceModels(self, request, context):
        """List namespace models

        Returns a paginated list of models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNamespaceModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of a namespace. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNamespaceModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent namespace.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNamespaceModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent namespace and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNamespaceModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameNamespaceModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchNamespaceModel(self, request, context):
        """Watch the state of a model version

        Returns the state of a model. The model resource allocation and scaling actions take some
        time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchNamespaceLatestModel(self, request, context):
        """Watch the state of the latest model version

        Returns the state of the latest model version. The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNamespaceModelVersions(self, request, context):
        """List namespace model versions

        Returns a paginated list of version of a model namespace that belong to the specified namespace.
        Contains model version and digest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNamespaceModelVersion(self, request, context):
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model, and version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceModel(self, request, context):
        """Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncNamespaceModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceLatestModel(self, request, context):
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncNamespaceLatestModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceLatestModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers the latest deployed model version to infer the result of a set of task or
        questions, submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNamespaceLatestModelOperation(self, request, context):
        """Get the details of the latest long-running operation from a namespace model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOperation(self, request, context):
        """Get the details of a long-running operation

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserModels(self, request, context):
        """The following endpoints are all deprecated

        List user models

        Returns a paginated list of models that belong to the specified user. The
        parent user may be different from the authenticated user, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of a user. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent user and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameUserModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUserModel(self, request, context):
        """Watch the state of a model version

        Returns the state of a model. The model resource allocation and scaling actions take some
        time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUserLatestModel(self, request, context):
        """Watch the state of the latest model version

        Returns the state of the latest model version. The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserModelVersions(self, request, context):
        """List user model versions

        Returns a paginated list of version of a model namespace that belong to the specified user.
        Contains model version and digest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserModelVersion(self, request, context):
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent user and the ID of the model, and version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncUserModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserLatestModel(self, request, context):
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncUserLatestModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationModels(self, request, context):
        """List organization models

        Returns a paginated list of models that belong to the specified organization. The
        parent organization may be different from the authenticated organization, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of an organization. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent organization and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameOrganizationModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchOrganizationModel(self, request, context):
        """Watch the state of a model version

        Returns the state of a model.  The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchOrganizationLatestModel(self, request, context):
        """Watch the state of the latest model version

        Returns the state of the latest model version.  The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationModelVersions(self, request, context):
        """List organization model versions

        Returns a paginated list of version of a model namespace that belong to the specified organization.
        Contains model version and digest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationModelVersion(self, request, context):
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model, and version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncOrganizationModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationLatestModel(self, request, context):
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncOrganizationLatestModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserLatestModelOperation(self, request, context):
        """Get the details of the latest long-running operation from a user model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationLatestModelOperation(self, request, context):
        """Get the details of the latest long-running operation from a organization model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.SerializeToString,
            ),
            'ListModelDefinitions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelDefinitions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.SerializeToString,
            ),
            'ListAvailableRegions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAvailableRegions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsResponse.SerializeToString,
            ),
            'GetModelDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelDefinition,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.SerializeToString,
            ),
            'LookUpModel': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.SerializeToString,
            ),
            'ListNamespaceModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamespaceModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsResponse.SerializeToString,
            ),
            'CreateNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelResponse.SerializeToString,
            ),
            'GetNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelResponse.SerializeToString,
            ),
            'UpdateNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelResponse.SerializeToString,
            ),
            'DeleteNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelResponse.SerializeToString,
            ),
            'RenameNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelResponse.SerializeToString,
            ),
            'WatchNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelResponse.SerializeToString,
            ),
            'WatchNamespaceLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchNamespaceLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelResponse.SerializeToString,
            ),
            'ListNamespaceModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamespaceModelVersions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsResponse.SerializeToString,
            ),
            'DeleteNamespaceModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNamespaceModelVersion,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionResponse.SerializeToString,
            ),
            'TriggerNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelResponse.SerializeToString,
            ),
            'TriggerAsyncNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelResponse.SerializeToString,
            ),
            'TriggerNamespaceLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerNamespaceLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelResponse.SerializeToString,
            ),
            'TriggerAsyncNamespaceLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncNamespaceLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelResponse.SerializeToString,
            ),
            'TriggerNamespaceModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerNamespaceModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadResponse.SerializeToString,
            ),
            'TriggerNamespaceLatestModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerNamespaceLatestModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetNamespaceLatestModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNamespaceLatestModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationResponse.SerializeToString,
            ),
            'GetModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.SerializeToString,
            ),
            'ListUserModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.SerializeToString,
            ),
            'CreateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.SerializeToString,
            ),
            'GetUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.SerializeToString,
            ),
            'UpdateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.SerializeToString,
            ),
            'DeleteUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.SerializeToString,
            ),
            'RenameUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.SerializeToString,
            ),
            'WatchUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.SerializeToString,
            ),
            'WatchUserLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchUserLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelResponse.SerializeToString,
            ),
            'ListUserModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserModelVersions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsResponse.SerializeToString,
            ),
            'DeleteUserModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserModelVersion,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionResponse.SerializeToString,
            ),
            'TriggerUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.SerializeToString,
            ),
            'TriggerAsyncUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelResponse.SerializeToString,
            ),
            'TriggerUserLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerUserLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelResponse.SerializeToString,
            ),
            'TriggerAsyncUserLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncUserLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelResponse.SerializeToString,
            ),
            'TriggerUserModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerUserModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.SerializeToString,
            ),
            'ListOrganizationModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.SerializeToString,
            ),
            'CreateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.SerializeToString,
            ),
            'GetOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.SerializeToString,
            ),
            'UpdateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.SerializeToString,
            ),
            'DeleteOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.SerializeToString,
            ),
            'RenameOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.SerializeToString,
            ),
            'WatchOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.SerializeToString,
            ),
            'WatchOrganizationLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchOrganizationLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelResponse.SerializeToString,
            ),
            'ListOrganizationModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationModelVersions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsResponse.SerializeToString,
            ),
            'DeleteOrganizationModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationModelVersion,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionResponse.SerializeToString,
            ),
            'TriggerOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.SerializeToString,
            ),
            'TriggerAsyncOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelResponse.SerializeToString,
            ),
            'TriggerOrganizationLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOrganizationLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelResponse.SerializeToString,
            ),
            'TriggerAsyncOrganizationLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncOrganizationLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelResponse.SerializeToString,
            ),
            'TriggerOrganizationModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetUserLatestModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserLatestModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationResponse.SerializeToString,
            ),
            'GetOrganizationLatestModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationLatestModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'model.model.v1alpha.ModelPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPublicService(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Liveness',
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Readiness',
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModelDefinitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAvailableRegions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListAvailableRegions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/LookUpModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNamespaceModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListNamespaceModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchNamespaceLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchNamespaceLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNamespaceModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListNamespaceModelVersions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNamespaceModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModelVersion',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncNamespaceLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceLatestModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNamespaceLatestModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetNamespaceLatestModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListUserModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchUserLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchUserLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListUserModelVersions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteUserModelVersion',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerUserLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncUserLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchOrganizationLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchOrganizationLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListOrganizationModelVersions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModelVersion',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncOrganizationLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserLatestModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserLatestModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationLatestModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationLatestModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n vdp/pipeline/v1beta/secret.proto\x12\x13vdp.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\xa1\x03\n\x06Secret\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x41\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x1f\n\x05value\x18\x06 \x01(\tB\x04\xe2\x41\x01\x04H\x00R\x05value\x88\x01\x01\x12&\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64\x65scription:v\xea\x41s\n\x17\x61pi.instill.tech/Secret\x12#users/{user.id}/secrets/{secret.id}\x12\x33organizations/{organization.id}/secrets/{secret.id}B\x08\n\x06_value\"|\n\x1c\x43reateNamespaceSecretRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x33\n\x06secret\x18\x02 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"Z\n\x1d\x43reateNamespaceSecretResponse\x12\x39\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x04\xe2\x41\x01\x03R\x06secret\"\xb5\x01\n\x1bListNamespaceSecretsRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12&\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\xae\x01\n\x1cListNamespaceSecretsResponse\x12;\n\x07secrets\x18\x01 \x03(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x04\xe2\x41\x01\x03R\x07secrets\x12,\n\x0fnext_page_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\rnextPageToken\x12#\n\ntotal_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\ttotalSize\"g\n\x19GetNamespaceSecretRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12!\n\tsecret_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x08secretId\"Q\n\x1aGetNamespaceSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\xe2\x01\n\x1cUpdateNamespaceSecretRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12!\n\tsecret_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x08secretId\x12\x33\n\x06secret\x18\x03 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\x12\x41\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"T\n\x1dUpdateNamespaceSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"j\n\x1c\x44\x65leteNamespaceSecretRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12!\n\tsecret_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x08secretId\"\x1f\n\x1d\x44\x65leteNamespaceSecretResponse\"\x9a\x01\n\x17\x43reateUserSecretRequest\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\x12J\n\x06parent\x18\x02 \x01(\tB2\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parent\"O\n\x18\x43reateUserSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\xd3\x01\n\x16ListUserSecretsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12J\n\x06parent\x18\x03 \x01(\tB2\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x97\x01\n\x17ListUserSecretsResponse\x12\x35\n\x07secrets\x18\x01 \x03(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"e\n\x14GetUserSecretRequest\x12M\n\x04name\x18\x01 \x01(\tB9\x92\x41\x16\xca>\x13\xfa\x02\x10user_secret_name\xe2\x41\x01\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"L\n\x15GetUserSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\x97\x01\n\x17UpdateUserSecretRequest\x12\x39\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x04\xe2\x41\x01\x02R\x06secret\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"O\n\x18UpdateUserSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"h\n\x17\x44\x65leteUserSecretRequest\x12M\n\x04name\x18\x01 \x01(\tB9\x92\x41\x16\xca>\x13\xfa\x02\x10user_secret_name\xe2\x41\x01\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"\x1a\n\x18\x44\x65leteUserSecretResponse\"\xaa\x01\n\x1f\x43reateOrganizationSecretRequest\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\x12R\n\x06parent\x18\x02 \x01(\tB:\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parent\"W\n CreateOrganizationSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\xe3\x01\n\x1eListOrganizationSecretsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12R\n\x06parent\x18\x03 \x01(\tB:\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x9f\x01\n\x1fListOrganizationSecretsResponse\x12\x35\n\x07secrets\x18\x01 \x03(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"u\n\x1cGetOrganizationSecretRequest\x12U\n\x04name\x18\x01 \x01(\tBA\x92\x41\x1e\xca>\x1b\xfa\x02\x18organization_secret_name\xe2\x41\x01\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"T\n\x1dGetOrganizationSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\x9f\x01\n\x1fUpdateOrganizationSecretRequest\x12\x39\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x04\xe2\x41\x01\x02R\x06secret\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"W\n UpdateOrganizationSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"x\n\x1f\x44\x65leteOrganizationSecretRequest\x12U\n\x04name\x18\x01 \x01(\tBA\x92\x41\x1e\xca>\x1b\xfa\x02\x18organization_secret_name\xe2\x41\x01\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"\"\n DeleteOrganizationSecretResponseB\xda\x01\n\x17\x63om.vdp.pipeline.v1betaB\x0bSecretProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\013SecretProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _SECRET.fields_by_name['name']._options = None
  _SECRET.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _SECRET.fields_by_name['uid']._options = None
  _SECRET.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _SECRET.fields_by_name['id']._options = None
  _SECRET.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _SECRET.fields_by_name['create_time']._options = None
  _SECRET.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _SECRET.fields_by_name['update_time']._options = None
  _SECRET.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _SECRET.fields_by_name['value']._options = None
  _SECRET.fields_by_name['value']._serialized_options = b'\342A\001\004'
  _SECRET.fields_by_name['description']._options = None
  _SECRET.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _SECRET._options = None
  _SECRET._serialized_options = b'\352As\n\027api.instill.tech/Secret\022#users/{user.id}/secrets/{secret.id}\0223organizations/{organization.id}/secrets/{secret.id}'
  _CREATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _CREATENAMESPACESECRETRESPONSE.fields_by_name['secret']._options = None
  _CREATENAMESPACESECRETRESPONSE.fields_by_name['secret']._serialized_options = b'\342A\001\003'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['secrets']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['secrets']._serialized_options = b'\342A\001\003'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\342A\001\003'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['total_size']._serialized_options = b'\342A\001\003'
  _GETNAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _GETNAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _GETNAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\342A\001\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\342A\001\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _DELETENAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _DELETENAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\342A\001\002'
  _CREATEUSERSECRETREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERSECRETREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\031\022\027api.instill.tech/Secret'
  _LISTUSERSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERSECRETSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\031\022\027api.instill.tech/Secret'
  _GETUSERSECRETREQUEST.fields_by_name['name']._options = None
  _GETUSERSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\026\312>\023\372\002\020user_secret_name\342A\001\002\372A\031\n\027api.instill.tech/Secret'
  _UPDATEUSERSECRETREQUEST.fields_by_name['secret']._options = None
  _UPDATEUSERSECRETREQUEST.fields_by_name['secret']._serialized_options = b'\342A\001\002'
  _UPDATEUSERSECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERSECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEUSERSECRETREQUEST.fields_by_name['name']._options = None
  _DELETEUSERSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\026\312>\023\372\002\020user_secret_name\342A\001\002\372A\031\n\027api.instill.tech/Secret'
  _CREATEORGANIZATIONSECRETREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONSECRETREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\031\022\027api.instill.tech/Secret'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\031\022\027api.instill.tech/Secret'
  _GETORGANIZATIONSECRETREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030organization_secret_name\342A\001\002\372A\031\n\027api.instill.tech/Secret'
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['secret']._options = None
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['secret']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEORGANIZATIONSECRETREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030organization_secret_name\342A\001\002\372A\031\n\027api.instill.tech/Secret'
  _globals['_SECRET']._serialized_start=233
  _globals['_SECRET']._serialized_end=650
  _globals['_CREATENAMESPACESECRETREQUEST']._serialized_start=652
  _globals['_CREATENAMESPACESECRETREQUEST']._serialized_end=776
  _globals['_CREATENAMESPACESECRETRESPONSE']._serialized_start=778
  _globals['_CREATENAMESPACESECRETRESPONSE']._serialized_end=868
  _globals['_LISTNAMESPACESECRETSREQUEST']._serialized_start=871
  _globals['_LISTNAMESPACESECRETSREQUEST']._serialized_end=1052
  _globals['_LISTNAMESPACESECRETSRESPONSE']._serialized_start=1055
  _globals['_LISTNAMESPACESECRETSRESPONSE']._serialized_end=1229
  _globals['_GETNAMESPACESECRETREQUEST']._serialized_start=1231
  _globals['_GETNAMESPACESECRETREQUEST']._serialized_end=1334
  _globals['_GETNAMESPACESECRETRESPONSE']._serialized_start=1336
  _globals['_GETNAMESPACESECRETRESPONSE']._serialized_end=1417
  _globals['_UPDATENAMESPACESECRETREQUEST']._serialized_start=1420
  _globals['_UPDATENAMESPACESECRETREQUEST']._serialized_end=1646
  _globals['_UPDATENAMESPACESECRETRESPONSE']._serialized_start=1648
  _globals['_UPDATENAMESPACESECRETRESPONSE']._serialized_end=1732
  _globals['_DELETENAMESPACESECRETREQUEST']._serialized_start=1734
  _globals['_DELETENAMESPACESECRETREQUEST']._serialized_end=1840
  _globals['_DELETENAMESPACESECRETRESPONSE']._serialized_start=1842
  _globals['_DELETENAMESPACESECRETRESPONSE']._serialized_end=1873
  _globals['_CREATEUSERSECRETREQUEST']._serialized_start=1876
  _globals['_CREATEUSERSECRETREQUEST']._serialized_end=2030
  _globals['_CREATEUSERSECRETRESPONSE']._serialized_start=2032
  _globals['_CREATEUSERSECRETRESPONSE']._serialized_end=2111
  _globals['_LISTUSERSECRETSREQUEST']._serialized_start=2114
  _globals['_LISTUSERSECRETSREQUEST']._serialized_end=2325
  _globals['_LISTUSERSECRETSRESPONSE']._serialized_start=2328
  _globals['_LISTUSERSECRETSRESPONSE']._serialized_end=2479
  _globals['_GETUSERSECRETREQUEST']._serialized_start=2481
  _globals['_GETUSERSECRETREQUEST']._serialized_end=2582
  _globals['_GETUSERSECRETRESPONSE']._serialized_start=2584
  _globals['_GETUSERSECRETRESPONSE']._serialized_end=2660
  _globals['_UPDATEUSERSECRETREQUEST']._serialized_start=2663
  _globals['_UPDATEUSERSECRETREQUEST']._serialized_end=2814
  _globals['_UPDATEUSERSECRETRESPONSE']._serialized_start=2816
  _globals['_UPDATEUSERSECRETRESPONSE']._serialized_end=2895
  _globals['_DELETEUSERSECRETREQUEST']._serialized_start=2897
  _globals['_DELETEUSERSECRETREQUEST']._serialized_end=3001
  _globals['_DELETEUSERSECRETRESPONSE']._serialized_start=3003
  _globals['_DELETEUSERSECRETRESPONSE']._serialized_end=3029
  _globals['_CREATEORGANIZATIONSECRETREQUEST']._serialized_start=3032
  _globals['_CREATEORGANIZATIONSECRETREQUEST']._serialized_end=3202
  _globals['_CREATEORGANIZATIONSECRETRESPONSE']._serialized_start=3204
  _globals['_CREATEORGANIZATIONSECRETRESPONSE']._serialized_end=3291
  _globals['_LISTORGANIZATIONSECRETSREQUEST']._serialized_start=3294
  _globals['_LISTORGANIZATIONSECRETSREQUEST']._serialized_end=3521
  _globals['_LISTORGANIZATIONSECRETSRESPONSE']._serialized_start=3524
  _globals['_LISTORGANIZATIONSECRETSRESPONSE']._serialized_end=3683
  _globals['_GETORGANIZATIONSECRETREQUEST']._serialized_start=3685
  _globals['_GETORGANIZATIONSECRETREQUEST']._serialized_end=3802
  _globals['_GETORGANIZATIONSECRETRESPONSE']._serialized_start=3804
  _globals['_GETORGANIZATIONSECRETRESPONSE']._serialized_end=3888
  _globals['_UPDATEORGANIZATIONSECRETREQUEST']._serialized_start=3891
  _globals['_UPDATEORGANIZATIONSECRETREQUEST']._serialized_end=4050
  _globals['_UPDATEORGANIZATIONSECRETRESPONSE']._serialized_start=4052
  _globals['_UPDATEORGANIZATIONSECRETRESPONSE']._serialized_end=4139
  _globals['_DELETEORGANIZATIONSECRETREQUEST']._serialized_start=4141
  _globals['_DELETEORGANIZATIONSECRETREQUEST']._serialized_end=4261
  _globals['_DELETEORGANIZATIONSECRETRESPONSE']._serialized_start=4263
  _globals['_DELETEORGANIZATIONSECRETRESPONSE']._serialized_end=4297
# @@protoc_insertion_point(module_scope)
